@@ -1,7 +1,8 @@
 # Internal function to check valid usage of methods
 .check_method <- function(
     method,
-    what = c("exists", "cv", "has_predict_method", "uses_index", "regress", "classify", "multinomial", "nonstandard_formula"),
+    what = c("exists", "cv", "has_predict_method", "has_importance_method", "uses_index",
+             "regress", "classify", "multinomial", "nonstandard_formula", "has_coef_method"),
     message = FALSE
     ) {
 
@@ -21,11 +22,11 @@
                 "pcr", "plsr", "hfr", "boost", "subset", "cor", "bayes", "quantile",
                 "glmm", "tvp", "mslm", "bma", "gets", "svm", "mrmr", "relief", "cor",
                 "chisq", "rf", "bridge", "blasso", "spikeslab", "genetic",
-                "quantile_rf"),
+                "quantile_rf", "anova", "nnet"),
     message = "'%s' is not a valid method. See '?m' for details"
   ),
   cv = list(
-    methods = c("lasso", "ridge", "enet", "adalasso", "pcr", "plsr", "hfr", "boost", "svm", "rf", "quantile_rf"),
+    methods = c("lasso", "ridge", "enet", "adalasso", "pcr", "plsr", "hfr", "boost", "svm", "rf", "quantile_rf", "nnet"),
     message = "'%s' has no hyperparameters. Use '.force_cv = TRUE' to perform a cross validation"
   ),
   has_predict_method = list(
@@ -33,7 +34,7 @@
                 "pcr", "plsr", "hfr", "boost", "subset", "bayes", "quantile",
                 "glmm", "tvp", "mslm", "bma", "gets", "svm",
                 "rf", "bridge", "blasso", "spikeslab", "genetic",
-                "quantile_rf"),
+                "quantile_rf", "nnet"),
     message = "'%s' has no predict method."
   ),
   uses_index = list(
@@ -44,20 +45,31 @@
     methods = c("lm", "glm", "robust", "lasso", "ridge", "enet", "adalasso",
                 "pcr", "plsr", "hfr", "boost", "subset", "cor", "bayes", "quantile",
                 "glmm", "tvp", "mslm", "bma", "gets", "svm", "mrmr", "relief", "cor", "rf", "bridge", "blasso",
-                "spikeslab", "genetic", "quantile_rf"),
+                "spikeslab", "genetic", "quantile_rf", "anova", "nnet"),
     message = "'%s' cannot be used for regression"
   ),
   classify = list(
     methods = c("glm", "lasso", "ridge", "enet", "adalasso", "boost", "subset", "bayes", "glmm", "svm", "mrmr",
-                "relief", "chisq", "rf", "spikeslab"),
+                "relief", "chisq", "rf", "spikeslab", "anova", "nnet"),
     message = "'%s' cannot be used for classification"
   ),
   multinomial = list(
-    methods = c("ridge", "lasso", "enet", "adalasso", "svm", "mrmr", "relief", "chisq", "rf"),
+    methods = c("ridge", "lasso", "enet", "adalasso", "svm", "mrmr", "relief", "chisq", "rf", "nnet"),
     message = "'%s' cannot be used for multinomial classification"
   ),
   nonstandard_formula = list(
     methods = c("glmm"),
     message = "'%s' uses non-standard formula syntax"
+  ),
+  has_importance_method = list(
+    methods = c("lm", "glm", "lasso", "ridge", "enet", "adalasso", "rf", "quantile_rf", "subset", "gets", "nnet"),
+    message = "'%s' has no variable importance method"
+  ),
+  has_coef_method = list(
+    methods = c("lm", "glm", "robust", "lasso", "ridge", "enet", "adalasso",
+                "pcr", "plsr", "hfr", "boost", "subset", "cor", "bayes", "quantile",
+                "glmm", "tvp", "mslm", "bma", "gets", "svm", "mrmr", "relief", "cor",
+                "chisq", "bridge", "blasso", "spikeslab", "genetic", "anova"),
+    message = "'%s' has not coef method"
   )
 )
