@@ -38,7 +38,7 @@
 #'
 #' # Within 'regress' function
 #' fit <- regress(data, Return ~ ., m("rf"))
-#' tidyr::unnest(coef(fit), model_info)
+#' explain(fit)
 #'
 #' @seealso \code{\link{.fit.svm}}, \code{\link{.fit.boost}} and \code{\link{m}} methods
 #'
@@ -72,39 +72,6 @@
   invisible(self)
 }
 
-.coef.randomForest <- function(object, self = NULL, ...) {
-  if (self$mode == "regression") {
-    imp <- object$importance
-    estimates <- dplyr::as_tibble(imp) %>%
-      dplyr::mutate(term = rownames(imp), estimate = NA) %>%
-      dplyr::mutate(importanceSD = object$importanceSD[.data$term])
-  } else {
-    imp <- object$importance
-    imp_MDacc <- imp[, -(ncol(imp)-1):-ncol(imp)]
-    imp_Other <- imp[, (ncol(imp)-1):ncol(imp)]
-    estimates <- dplyr::as_tibble(imp_MDacc) %>%
-      dplyr::mutate(term = rownames(imp)) %>%
-      tidyr::pivot_longer(-"term", names_to = "class", values_to = "Class_MeanDecreaseAccuracy")
-    estimates_other <- dplyr::as_tibble(imp_Other) %>%
-      dplyr::mutate(term = rownames(imp))
-    estimates <- dplyr::left_join(estimates, estimates_other, by = "term")
-    impSD <- object$importanceSD
-    impSD_MDacc <- impSD[, -ncol(impSD)]
-    impSD_Other <- impSD[, ncol(impSD)]
-    estimatesSD <- dplyr::as_tibble(impSD_MDacc) %>%
-      dplyr::mutate(term = rownames(impSD)) %>%
-      tidyr::pivot_longer(-"term", names_to = "class", values_to = "Class_MeanDecreaseAccuracySD")
-    estimatesSD_other <- dplyr::tibble(MeanDecreaseAccuracySD = impSD_Other) %>%
-      dplyr::mutate(term = rownames(impSD))
-    estimatesSD <- dplyr::left_join(estimatesSD, estimatesSD_other, by = "term")
-    estimates <- estimates %>%
-      dplyr::left_join(estimatesSD, by = c("term", "class")) %>%
-      dplyr::mutate(estimate = NA)
-  }
-
-  return(estimates)
-}
-
 .predict.randomForest <- function(object, data, self = NULL, ...) {
   augmented_data <- dplyr::bind_rows(data, self$data)
   response_var <- all.vars(self$formula)[1]
