@@ -3,7 +3,7 @@ test_that("quantile rf regression works", {
   df_reg <- MASS::Boston
 
   m_reg <- m("quantile_rf", medv ~ ., df_reg, tau = 0.4)
-  expect_equal(nrow(coef(m_reg)), 14)
+  expect_equal(nrow(tidyfit::explain(m_reg)), 14)
   expect_equal(nrow(predict(m_reg, df_reg)), 506)
   expect_equal(nrow(fitted(m_reg)), 506)
   expect_equal(nrow(resid(m_reg)), 506)
